# DAC43608

Python library for the DAC43608

### Installation

```
pip3 install DAC43608
```


### Simple usage

```
from DAC43608 import DAC43608

dac = DAC43608()
dac.power_up(dac.A)
dac.set_intensity_to(dac.A, 0.75)
```

### What about the other 4 channels

Pull requests welcome!
